from setuptools import setup

setup(
    name='auto_dl',
    version='0.1',  # Update the version number for new releases
    url='https://github.com/bjherger/auto_dl',
    author='Brendan Herger',
    author_email='13herger@gmail.com',
    license='MIT',
    packages=['auto_dl'],
    zip_safe=False
)
